@@ -2,14 +2,16 @@ from tqdm import *
 from time import sleep
 import time
 from random import randint,choice
-from os import system,urandom
+from os import *
 from termcolor import colored
 import f61d.LOGO as LOGO
 #from f61d.__version__ import *
 from math import ceil
 from tqdm import *
+from setu import setu,getDesktop
 
-VERSION = (0,4,3)
+
+VERSION = (0,5,0)
 VERSION = '.'.join(map(str, VERSION))
 
 
@@ -29,9 +31,11 @@ help_cont[7] = 'getLogo  : Print the "F61D" LOGO.'
 help_cont[8] = 'yinyang  : Draw the TaiJi.'
 help_cont[2] = 'timeit   : Take a time for your function.\n\t\t  Just add a '+colored('@timeit','cyan')+colored(' before you define the function','green')
 help_cont[10] = 'Polynomial: from f61d.Polynomial2 import *'
-help_cont[11] = 'gmgj     : Common Modulus Attack in RSA'
-help_cont[12] = 'crt      : Chinese Remainder Theory'
-help_cont[12] = 'mtank     : 幻影坦克 Mirage tank maker'
+help_cont[11] = 'gmgj    : Common Modulus Attack in RSA'
+help_cont[12] = 'crt     : Chinese Remainder Theory'
+help_cont[12] = 'mtank   : 幻影坦克 Mirage tank maker'
+help_cont[13] = 'setu    : get a setu (or save it)'
+
 
 def formatNumber(x):
     if len(str(x)) == 1:
@@ -145,14 +149,21 @@ def prove(cont,process_bar=True,show_description=False):
     '''
     Only the format is supported
     sha256(XXXX + {a}) = {b}
+    Example:
+
+    >>> r = remote("127.0.0.1",6666)
+    >>> PoW = r.recvuntil(">")
+    >>> r.sendline(f61d.prove(PoW.encode()))
+    >>> r.interactive()
+        
     '''
     if process_bar and show_description:
-        print("Open tqdm bar and description may be VERY SLOW.\nDescription is not sugested.")
+        print("Open tqdm bar and description may be VERY SLOW.\nDescription is not suggested.")
     from itertools import product
     import re
     from string import ascii_letters,digits
     from hashlib import sha256
-
+    from tqdm import tqdm
     
     cont = cont.replace(' ','')
     #print(cont)
@@ -238,10 +249,12 @@ def mtank(outerPic,innerPic,output='tank.png'):
     from PIL import Image as img
     from f61d.tank import make
     if output.split('.')[-1] != 'png':
-        print('')
-        raise 
+        print('Output file type must be PNG')
+        raise ValueError
+    
     p1 = img.open(outerPic)
     p1 = p1.convert('L')
     p2 = img.open(innerPic)
     p2 = p2.convert('L')
-    make(p1,p2,output)
+    make(p1,p2,getDesktop + '\\' + output)
+
